@@ -10,7 +10,7 @@ class Carrot(tk.Canvas):
     def __init__(self, layout):
 
         self.__layout = layout
-        self.__bkg = "default-bkg.png"
+        self.__bkg = "./default-bkg.png"
         self.__width, self.__height = layout.get_dimensions()
         self.__border_width = 1
 
@@ -47,10 +47,10 @@ class Carrot(tk.Canvas):
         self.create_window(x, y, anchor=tk.CENTER, window=widget)
         return widget
     
-    def add_styled_button(self, text, anchor, bcolor, fcolor, w, h, bd, style, command, x, y):
+    def add_styled_button(self, text, bcolor, fcolor, w, h, bd, style, command, x, y):
         h = self.add_widget(tk.Button(self, 
                                 text = text, 
-                                anchor = anchor,
+                                anchor = tk.CENTER,
                                 bg = bcolor,
                                 foreground = fcolor,
                                 width = w,
